/**
 * Stores, reads and alters Kobold Adventure settings.
 */
function Settings() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var settingsSlot = "settings";

    var flatChest = "flatchest";
    var hotLoad = "hotload";
    var oldLoad = "oldLoad"
    var hideNsfw = "hidensfw";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Gets the setting with the passed key.
     * @param {string} key The key of the setting.
     * @returns {?} The setting.
     */
    function getSetting(key) {
        var json = localStorage.getItem(settingsSlot) || "{}";
        var obj = JSON.parse(json);
        return obj[key];
    }

    /**
     * Sets the setting with the passed key to the passed value.
     * @param {string} key The key of the setting.
     * @param {?} value The value to set the setting to.
     */
    function setSetting(key, value) {
        var json = localStorage.getItem(settingsSlot) || "{}";
        var obj = JSON.parse(json);
        obj[key] = value;
        localStorage.setItem(settingsSlot, JSON.stringify(obj));
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Gets the flat chested female setting.
     * @returns {undefined | boolean} May return undefined, true or false depending on whether the setting has been set or not. Undefined is to be treated as false.
     */
    this.getFlatChestedFemale = function () {
        return getSetting(flatChest);
    };

    /**
     * Sets the flat chested female setting.
     * @param {boolean} value The value to set it to.
     */
    this.setFlatChestedFemale = function (value) {
        setSetting(flatChest, value);
    };

    /**
     * Gets the hotload setting.
     * @returns {undefined | boolean} May return undefined, true or false depending on whether the setting has been set or not. Undefined is to be treated as false.
     */
    this.getHotLoad = function () {
        return getSetting(hotLoad);
    };

    /**
     * Sets the hotload setting.
     * @param {boolean} value The value to set it to.
     */
    this.setHotLoad = function (value) {
        setSetting(hotLoad, value);
    };

    /**
     * Gets the old load setting.
     * @returns {undefined | boolean} May return undefined, true or false depending on whether the setting has been set or not. Undefined is to be treated as false.
     */
    this.getOldLoad = function () {
        return getSetting(oldLoad);
    };

    /**
     * Sets the old load setting.
     * @param {boolean} value The value to set it to.
     */
    this.setOldLoad = function (value) {
        setSetting(oldLoad, value);
    };

    /**
     * Gets the hide NSFW setting.
     * @returns {undefined | boolean} May return undefined, true or false depending on whether the setting has been set or not. Undefined is to be treated as false.
     */
    this.getHideNsfw = function () {
        return getSetting(hideNsfw);
    };

    /**
     * Sets the hide NSFW setting.
     * @param {boolean} value The value to set it to.
     */
    this.setHideNsfw = function (value) {
        setSetting(hideNsfw, value);
    };
}

