/**
 * This class represents the popup menu.
 * Its init() function should be called immediately upon successful project load.
 */
function PopupMenu() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var popupId = "menupopup";
    var menuId = "menu";
    var openButtonId = "menuopenbutton";
    var subtitleId = "menusubtitle";
    var contentId = "menucontent";
    var closeButtonId = "menuclosebutton";
    var invisibleClass = "popupmenuinvisible";

    var subtitleDefault = false;
    var contentDefault = false;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Stops event propagation.
     * @param {event} event The event to stop propagation of.
     */
    function stopProp(event) {
        event.stopPropagation();
    }

    /**
     * Function called when no button is clicked.
     * @param {event} event The click event.
     */
    function noButton(event) {
        if (!subtitleDefault || !contentDefault) {
            that.buttons.unset();
        }
        stopProp(event);
    }

    /**
     * Registers the button listener for the menu button.
     */
    function registerListeners() {
        $("#" + popupId).click(that.hide);
        $("#" + closeButtonId).click(that.hide);
        $("#" + menuId).click(noButton);
        $("#" + openButtonId).click(that.show);
    }

    /**
     * Resets the menu's text and makes it invisible.
     */
    function reset() {
        $("#" + menuId).addClass(invisibleClass);
        that.resetContent();
        that.resetSubtitle();
    }

    /**
     * Makes the menu visible after it being reset.
     */
    function expand() {
        $("#" + menuId).removeClass(invisibleClass);
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // Buttons contained in this menu.
    this.buttons = new AllMenuButtons();

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Initializes the UI controller.
     */
    this.init = function () {
        that.buttons.init();
        registerListeners();
        reset();
    };

    /**
     * Shows the menu.
     */
    this.show = function () {
        that.buttons.unset();
        $("#" + popupId).fadeIn(400);
        expand();
    };

    /**
     * Fades out the menu.
     */
    this.hide = function () {
        $("#" + popupId).fadeOut(400, reset);
    };

    /**
     * Sets the subtitle of the popup menu.
     * @param {string} subtitle The new subtitle.
     */
    this.setSubtitle = function (subtitle) {
        subtitleDefault = false;
        $("#" + subtitleId).html(subtitle);
    };

    /**
     * Sets the content of the popup menu.
     * @param {string} content The new content.
     */
    this.setContent = function (content) {
        contentDefault = false;
        $("#" + contentId).html(content);
    };

    /**
     * Resets the subtitle of the popup menu.
     */
    this.resetSubtitle = function () {
        if (subtitleDefault) {
            return;
        }
        subtitleDefault = true;
        that.setSubtitle("Instructions");
    };

    /*
     * Resets the content of the popup menu.
     */
    this.resetContent = function () {
        if (contentDefault) {
            return;
        }
        contentDefault = true;
        that.setContent(`Welcome to the Kobold Adventure menu!
                    In here, you can find a bunch of links to interesting features you may want to check out.
                    Click on one of the buttons below to get more information on what it entails.
                    Clicking on a button after it's been selected will open the specified page in a new tab.
                    Click anywhere outside of this window, or on the big X at the top right corner, to close this window.`);
    };
}
