/**
 * Hide from the scream on the path home.
 * @param {ForestController} controller The forest controller.
 */
function ForestHomeHide(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = "continueButton";

    var content = ` <div class="text">
                        The shrill shriek sends shivers down your spine.
                        You jump into a nearby bush, cower in fear and try to stifle your panicked breathing.
                        You've heard terrible tales of phantoms, spectres and plenty more otherwordly creatures that are said to haunt these very woods.
                        Of course, you <span class="sneakytext bold">no longer</span> believe in ghosts, but that shout you just heard was <span class="bold">very</span> real.
                    </div>
                    <div class="text">
                        You remain concealed as the scream is followed by a bunch of wails and moans of a disconcerting nature.
                        Luckily enough, their source seems to be stationary. 
                        Or at least, they don't seem to be growing noticably louder or softer.
                        With ghosts, you can never be certain.
                        You aren't even sure whether these <span class="italic">shrieks</span> are physical, or just a mental manifestation of whatever phantom you've encountered.
                        You notice the sound appears to be echoing off the trees surrounding you. 
                        That poltergeist sure is good at creating lifelike audio-illusions!
                    </div>
                    <div class="text">
                        Suddenly, the latest high-pitched whine to ring through your ears abruptly ends, as though silenced.
                        Oddly enough, the silence proves to be <span class="bold">more</span> unsettling than the wailing ever was.
                        Did the ghost leave?
                        Did someone <span class="span">kill</span> it?
                        Is it even possible to <span class="span">kill</span> a ghost?
                        Maybe <span class="span">banish</span> would be a better word.
                    </div>
                    <div class="text">
                        You remain in the bush for nearly an entire hour more, 
                        <span class="italic">contemplating the mortality of ghosts</span>, 
                        and totally not being scared shitless by the thought of a phantasm taking control of your body and making you`;
    
    var contentEnd = `  What grown-up kobold would be afraid of such silly things? 
                        Not you, that's for sure!
                      </div>
                      <div class="text">
                        As the sun is slowly starting to set, you decide to emerge from the bush once more.
                        You <span class="bold">don't</span> want to be around here come nightfall.
                        It's about time to resume your journey home.
                      </div>`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the weapon dependent part of this section.
     * @returns {string} The weapon dependent part of this section.
     */
    function buildWeaponDependentPart() {
        var weapon = ctrl.home.hideWeapon();
        if(weapon) {
            return ` hit yourself on the head with your ${global.kobold.inventory.createItemWithTooltip(weapon)} until your brains spill out.`;
        } else {
            return ` claw your own eyes out.`;
        }
    }

    /**
     * Builds and returns the main content of this section.
     * @returns {string} The main content of this section.
     */
    function buildContent() {
        return content + buildWeaponDependentPart() + contentEnd;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var disabled = ctrl.home.hideHasContinued();
        var choice = `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     */
    function loadNextPart() {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(ctrl.homeSceneName);
        });
    }

    /**
     * Adds a listener to the continue button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.home.hideContinue();
            loadNextPart();
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeHide";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.home.hasMadePathChoice()) {
            return "";
        }
        if(ctrl.home.getPathChoice() !== ForestHomePathChoiceEnum.HIDE) {
            return "";
        }
        
        var change = ctrl.home.hideStatusChange();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if(ctrl.home.getPathChoice() !== ForestHomePathChoiceEnum.HIDE) {
            return;
        }
        if(ctrl.home.hideHasContinued()) {
            return;
        }
        
        registerContinueListener();
    };
}
