/**
 * The path to home of the Forest scene.
 * @param {ForestController} controller The forest controller.
 * @param {ForestWoodsUnknown} toUnknown A part the kobold may go to next.
 * @param {ForestHomeHide} toHide A part the kobold may go to next.
 * @param {ForestBandit} toBandit A part the kobold may go to next.
 */
function ForestWoodsArrival(controller, toUnknown, toHide, toBandit) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;
    var unknown = toUnknown;
    var hide = toHide;
    var bandit = toBandit;

    var unknownId = "woodsUnknownButton";
    var hideId = "woodsHideButton";
    var knownId = "woodsKnownButton";

    var content = ` <div class="text">
                        You decide to venture deeper into the woods, to try and shake off any would-be pursuers.
                        While you lack a map, you know exactly where you are: the large stretch of woodland between the
                        eastern and the southern roads to Varanar. The southern path is where you ambushed the money transport,
                        and your home lies near a little bit off the eastern route. You form a mental image of your surroundings.
                    </div>
                    <div class="text center">
                        <a href="scenes/Forest/woods/arrival/woodsmap.png" target="_blank">
                            <img class="sfw" src="scenes/Forest/woods/arrival/woodsmap.png">
                        </a>
                    </div>
                    <div class="text">
                        Since you want to avoid the roads, and you'll just end up getting blocked off by the river if you head northwest, 
                        you wisely head off towards the southeast, into the denser parts of the forest.
                        You walk at a steady pace, sheer determination driving your weary legs to carry your lithe frame throughout the maze
                        of trees.
                    </div>
                    <div class="text">
                        After nearly half an hour of hiking, you take a little break.
                        You've made considerable progress into the forest, and you're nearing parts you've only rarely ventured into.
                        There's no telling what you might find should you press on, but do you really want to go exploring with a large sum of money dangling from your neck?
                        Alternatively, you could keep wandering about, yet restrict yourself to familiar territory.
                        That way, you can stay ahead of whoever may or may not be chasing you, without risking being unable to find your way home once the sun sets.
                        Or you could just stop walking altogether, and try to conceal yourself as best you can in the area you are in right now.
                    </div>`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the main content of this section.
     * @returns {string} The main content of this section.
     */
    function buildContent() {
        return content;
    }

    /**
     * Builds and returns the investigate choice button.
     */
    function buildUnknownChoice() {
        var disabled = ctrl.woods.hasMadeArrivalChoice() ? "disabled" : "";
        var isSelected = ctrl.woods.getArrivalChoice() == ForestWoodsArrivalChoiceEnum.UNKNOWN;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${unknownId}" ${disabled} style="font-size: 18px;">Venture into the unknown</button>`;

        var tooltip = `Head into parts of the forest you've never really been to before. <span class="todo">Content, but dead end</span>`;
        var popupContainer = global.ui.makeToolTip(button, tooltip);
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the hide choice button.
     */
    function buildHideChoice() {
        var disabled = ctrl.woods.hasMadeArrivalChoice() ? "disabled" : "";
        var isSelected = ctrl.woods.getArrivalChoice() == ForestWoodsArrivalChoiceEnum.HIDE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${hideId}" ${disabled}>Hide</button>`;

        var tooltip = `Hide from the men who may or may not be pursuing you.`;
        var popupContainer = global.ui.makeToolTip(button, tooltip);
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the ignore choice button.
     */
    function buildKnownChoice() {
        var disabled = ctrl.woods.hasMadeArrivalChoice() ? "disabled" : "";
        var isSelected = ctrl.woods.getArrivalChoice() == ForestWoodsArrivalChoiceEnum.KNOWN;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${knownId}" ${disabled} style="font-size: 18px;">Venture into the known</button>`;

        var tooltip = `Explore relatively known parts of the forest and attempt to find something new.`;
        var popupContainer = global.ui.makeToolTip(button, tooltip);
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildUnknownChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildHideChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildKnownChoice();
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + unknownId), $("#" + hideId), $("#" + knownId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {ForestWoodsArrivalChoiceEnum} next Which part to load.
     */
    function loadNextPart(next) {
        var part;
        if (next === ForestWoodsArrivalChoiceEnum.UNKNOWN) {
            part = unknown;
        }
        if (next === ForestWoodsArrivalChoiceEnum.HIDE) {
            part = hide;
        }
        if (next === ForestWoodsArrivalChoiceEnum.KNOWN) {
            part = bandit;
        }
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the unknown button.
     */
    function registerUnknownListener() {
        $("#" + unknownId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.woods.makeArrivalChoice(ForestWoodsArrivalChoiceEnum.UNKNOWN);
            loadNextPart(ForestWoodsArrivalChoiceEnum.UNKNOWN);
        });
    }
    
    /**
     * Adds a listener to the known button.
     */
    function registerHideListener() {
        $("#" + hideId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.woods.makeArrivalChoice(ForestWoodsArrivalChoiceEnum.HIDE);
            loadNextPart(ForestWoodsArrivalChoiceEnum.HIDE);
        });
    }

    /**
     * Adds a listener to the known button.
     */
    function registerKnownListener() {
        $("#" + knownId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.woods.makeArrivalChoice(ForestWoodsArrivalChoiceEnum.KNOWN);
            ctrl.bandit.setSource(ForestBanditSourceEnum.WOODS);
            loadNextPart(ForestWoodsArrivalChoiceEnum.KNOWN);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "woodsArrival";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        var change = ctrl.woods.arrivalStatusChange();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += `</div>`;
        part += bandit.build();
        part += unknown.build();
        part += hide.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        unknown.registerListeners();
        bandit.registerListeners();
        hide.registerListeners();
        
        if (ctrl.woods.hasMadeArrivalChoice()) {
            return;
        }
        
        registerUnknownListener();
        registerKnownListener();
        registerHideListener();
    };
}

/**
 * Path choices to be made.
 */
var ForestWoodsArrivalChoiceEnum = {
    UNKNOWN: 1,
    HIDE: 2,
    KNOWN: 3
};
