/**
 * Steal section of the Farmer House scene.
 * @param {BreedingFarmController} controller The Farmer House controller.
 */
function FarmerHousePry(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var nextId = arguments.callee.name + "ButtonOne";
    var next = new FarmerHouseCabinetRun(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            The compartiment at the bottom of the cabinet probably contains the best goodies.
                            It makes sense, right?
                            Biggest storage, best stuff.
                            You take hold of the metallic handle attached to the wooden door, and firmly [b]yank[/b] it backwards,
                            but it absolutely [b]refuses[/b] to budge.
                            You don't know whether there's some kind of lock you're not seeing, if the hinges are rusted, or if the wood is somehow blocked.
                        [/p]
                        [p]
                            Annoyed, you begin to tug at the jammed door, briskly rattling it back and forth to little effect.
                            You stop once you become aware of the noise you're making.
                            Luckily, the woman doesn't seem to notice.
                            The walls of this house, while rotten, must be pretty thick.
                        [/p]
                        [p]
                            You go for a new approach.
                            Applying pressure to the winch-side of the door with one hand, you start to steadily pull on the handle with the other.
                            You begin to exert ever-intensifying force.
                            The wood begins to creak and crack.
                            Right as you think you've [b]nearly[/b] got it, the entire thing gives way!
                            While you had meant to force the door open, you [b]tear[/b] it from the cupboard as a whole,
                            the decaying wood no longer suffice to hold the winches in place.
                        [/p]
                        [p]
                            The cabinet breaks open surprisingly quietly.
                            You place the torn-off door on the floor.
                            The contents of the cupboard are revealed to you:
                            a single, tiny bag of gold, which you presume to be the farmer's life savings.
                            A small amount of coins stashed away for a rainy day.
                        [/p]
                        [p]
                            While you do feel kind of bad for the peasant family, you probably need this money more than they do.
                            They may be pretty low on the social ladder, but they're still [b]humans[/b].
                            They have rights, and laws protecting them and whatnot.
                            Compared to you, they'll have an easy life even without this coin purse.
                            Besides, you're a thief.
                            Stealing is just what you [i]do[/i].
                            It's in your nature.
                            In your blood.
                        [/p]
                        [p]
                            This isn't the time to grow remorseful.
                            You pocket the bag of coins.
                            There's no point in trying to [i]fix[/i] the cabinet.
                            You leave the broken part on the floor, and slip out the back door from whence you came.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = ctrl.cabinetSteal.continued() ? "disabled" : "";
        var isSelected = ctrl.cabinetSteal.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${nextId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + nextId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + nextId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.cabinetSteal.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.cabinet.get() !== FarmerHouseCabinetChoice.PRY) {
            return "";
        }
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.cabinetSteal.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.cabinet.get() !== FarmerHouseCabinetChoice.PRY) {
            return;
        }

        next.registerListeners();

        if (ctrl.cabinetSteal.continued()) {
            return;
        }

        registerNextListener();
    };
}
