/**
 * Controller for the Home scene.
 * @param {string} sceneId The id of the scene.
 */
function SekiWorkshopController(sceneId) {
    // PRIVATE MEMBERS \\       var private = "test";
    var id = sceneId;
    var genderId = "gender";
    var autoSaveId = "autoSave";
    var goldId = "gold";
    var continueId = "continue";
    var underwearId = "underwear";
    var pantsId = "pants";
    var braId = "bra";
    var shirtId = "shirt";
    var nameId = "name";
    var healthId = "health";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}
    function EntranceController(key) {
        this.continue = function () {
            global.kobold.history.setKey(id, key, true);
            global.kobold.history.shared.seki.knowsDying = true;
            global.kobold.history.shared.seki.hamletHadMoney = global.kobold.inventory.coins !== 0;
        };
        this.continued = function () {
            return global.kobold.history.has(id, key);
        };
    }

    function FreeController(key) {
        ContinueController.call(this, id, key);
        var changeKey = key + "change";
        this.change = function () {
            global.kobold.history.doIfNotSet(id, changeKey, true, function () {
                global.kobold.status.mental.decrease(20, "Bad news has wings");
                global.kobold.inventory.bag.addMisc(new Lockpick());
            });
            return global.ui.change.buildNotification([
                new Change("Free lockpick", "Lockpick", +1),
                new Change("Bad news", "Sanity", -20)
            ]);
        };
    }

    function BuyController(key) {
        var that = this;
        ContinueController.call(this, id, key);

        var shopItemKey = key + "Items";
        var shopGoldKey = key + "Gold";
        var initialShopItems = [
            new ItemAmount(1, new Dagger()),
            new ItemAmount(1, new LinenBra()),
            new ItemAmount(1, new KoboldUnderwear()),
            new ItemAmount(1, new LeatherPants()),
            new ItemAmount(1, new PaddedLeatherShirt()),
            new ItemAmount(1, new Rope()),
            new ItemAmount(4, new Lockpick()),
            new ItemAmount(1, new AgilityPotion()),
            new ItemAmount(1, new CharismaPotion()),
            new ItemAmount(1, new EndurancePotion()),
            new ItemAmount(1, new IntelligencePotion()),
            new ItemAmount(1, new LuckPotion()),
            new ItemAmount(1, new StrengthPotion()),
            new ItemAmount(1, new RejuvenationPotion()),
            new ItemAmount(2, new mPlus()),
            new ItemAmount(2, new Apple()),
            new ItemAmount(1, new HeartyMeal())
        ];
        var sellmod = 0.7;
        var buymod = 1.0;

        function sellListener(item) {
            var itemAmounts = that.shopItems();
            var added = false;
            for (var i = 0; i < itemAmounts.length && !added; i++) {
                if (itemAmounts[i].item.id === item.id) {
                    itemAmounts[i].amount++;
                    added = true;
                }
            }
            if (!added) {
                itemAmounts.push(new ItemAmount(1, item));
            }
            that.updateCoins();
            that.updateShopItems(itemAmounts);
        }

        function buyListener(location) {
            var oldCoins = that.coins();
            that.updateCoins();
            var newCoins = that.coins();
            var itemAmounts = that.shopItems();
            itemAmounts[location].amount--;
            that.updateShopItems(itemAmounts);
            global.kobold.history.shared.seki.moneySpent += oldCoins - newCoins;
        }

        this.getGenerator = function () {
            return new MerchantInventoryGenerator("SekiShop", that.shopItems(), that.coins(), sellmod, buymod, that.continued(), sellListener, buyListener);
        };
        this.coins = function () {
            global.kobold.history.setIfNotSet(id, shopGoldKey, global.kobold.inventory.coins);
            return global.kobold.history.getKey(id, shopGoldKey);
        };
        this.updateCoins = function () {
            global.kobold.history.setKey(id, shopGoldKey, global.kobold.inventory.coins);
        };
        this.shopItems = function () {
            global.kobold.history.setIfNotSet(id, shopItemKey, initialShopItems);
            var jsonItems = global.kobold.history.getKey(id, shopItemKey);
            var items = global.kobold.inventory.constructItemAmountListFromMemory(jsonItems);
            return items;
        };
        this.updateShopItems = function (newItems) {
            global.kobold.history.setKey(id, shopItemKey, newItems);
        };
    }

    function BuyContinueController(id, key) {
        this.continue = function () {
            global.kobold.history.setKey(id, key, true);
        };
        this.continued = function () {
            // Version 2.11 (Pitchfork) introduced a bug where the key used for the BuyContinueController was the id of the scene.
            // This fix ensures saves will not retroactively break.
            return global.kobold.history.has(id, key) || global.kobold.history.has(id, id); 
        };
        var changeKey = key + "change";
        this.change = function () {
            global.kobold.history.doIfNotSet(id, changeKey, true, function () {
                global.kobold.status.mental.decrease(20, "Bad news has wings");
            });
            return global.ui.change.buildNotification([
                new Change("Bad news", "Sanity", -20)
            ]);
        };
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.folderName = "HamletDay2";
    this.breedingSceneName = "BreedingFarm";
    this.farmHomeSceneName = "FarmerHouse";
    this.minBuyGold = 50;
    this.arrival = new ContinueController(id, "arrival");
    this.entrance = new EntranceController("entrance");
    this.free = new FreeController("free");
    this.buy = new BuyController("buy");
    this.buyContinue = new BuyContinueController(id, "buyContinue");

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /*
     * Autosaves the game if necessary.
     */
    this.autosave = function () {
        global.kobold.history.doIfNotSet(id, autoSaveId, true, function () {
            global.saveManager.autoSave();
        });
    };

    /**
     * Signals the scene has been continued.
     */
    this.continue = function () {
        global.kobold.history.setKey(id, continueId, true);
    };

    /**
     * Returns whether or not the scene has continued.
     * @returns {boolean} True if the scene has continued, false otherwise.
     */
    this.continued = function () {
        return global.kobold.history.has(id, continueId);
    };

    this.gold = function () {
        global.kobold.history.setIfNotSet(id, goldId, global.kobold.inventory.coins);
        return global.kobold.history.getKey(id, goldId);
    };

    this.pants = function () {
        global.kobold.history.setIfNotSet(id, pantsId, global.kobold.inventory.equipment.pants);
        return global.kobold.inventory.equipment.buildGearFromHistory(global.kobold.history.getKey(id, pantsId));
    };

    this.bra = function () {
        global.kobold.history.setIfNotSet(id, braId, global.kobold.inventory.equipment.bra);
        return global.kobold.inventory.equipment.buildGearFromHistory(global.kobold.history.getKey(id, braId));
    };

    this.shirt = function () {
        global.kobold.history.setIfNotSet(id, shirtId, global.kobold.inventory.equipment.shirt);
        return global.kobold.inventory.equipment.buildGearFromHistory(global.kobold.history.getKey(id, shirtId));
    };

    this.underwear = function () {
        global.kobold.history.setIfNotSet(id, underwearId, global.kobold.inventory.equipment.underwear);
        return global.kobold.inventory.equipment.buildGearFromHistory(global.kobold.history.getKey(id, underwearId));
    };

    this.gender = function () {
        global.kobold.history.setIfNotSet(id, genderId, global.kobold.body.getBaseGender());
        return global.kobold.history.getKey(id, genderId);
    };

    this.name = function () {
        global.kobold.history.setIfNotSet(id, nameId, global.kobold.name);
        return global.kobold.history.getKey(id, nameId);
    };

    this.health = function () {
        global.kobold.history.setIfNotSet(id, healthId, global.kobold.status.physical.get());
        return global.kobold.history.getKey(id, healthId);
    };
}

