/**
 * The Title Screen scene. Shows up when Kobold Adventure gets loaded.
 */
function TitleScreen() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var content =  `<div class="title fancy" style="margin-bottom: 0px;">
                         welcome to
                    </div>
                    <div class="title fancy" style="font-size: 72px;">
                        KObOld Adventure
                    </div>

                    <p class="text">
                        Kobold Adventure is an adult, text-based adventure game. You will assume the role of a kobold, and try to survive
                        in a hostile medieval fantasy world. You will face many trials and tribulations before the end, and your life will
                        not be an easy one. Can you make it out alive, or will you fall prey to the many dangers of this world?
                    </p>

                    <hr class="smallseparator">

                    <p class="text">
                        In order to get the best experience out of Kobold Adventure, it is recommended that you play using a webkit
                        browser, such as Google Chrome. While the game will run on most if not all browsers, there is no guarantee 
                        that all features will be enabled. A very clear cut example of this is the custom scrollbar of the main 
                        game panel. If you are currently using a non-webkit browser, such as Microsoft Edge, Mozilla Firefox or 
                        Internet Explorer, you will most likely have an ugly default one. This may break the layout at certain places.
                    </p>

                    <p class="text">
                        <a href="scenes/TitleScreen/chibi-full.png" target="_blank">
                            <img class="sfw" style="float: right; width: 180px; margin-left: 20px; margin-top: -10px;" src="scenes/TitleScreen/chibi.png" alt="chibi kobold" title="Art by Sneaky">
                        </a>
                        Most, if not all images in Kobold Adventure are clickable.
                        Clicking them will open up the full-sized version of the image in a new tab.
                        Try it out on the small sketch to the right.
                        Not safe for work artwork  may be disabled via the settings menu,
                        which also contains a wealth of other configuration options.
                        This menu may be reached via a handy button in the bottom left corner.
                    </p>

                    <p class="text nomargin">
                        If you encounter any bugs, typos or oddities, the first step you should take is to empty your browser's cache and force a hard reload.
                        On most browsers, you can do this by pressing ctrl-F5.
                        Should the problem persist, don't hesitate to report it to the author of Kobold Adventure, TinkeringTurian.
                        He is reachable via four different channels: 
                    </p>

                    <ul class="summation">

                        <li class="text">
                            First and foremost, if you have a Steam account, you may report issues directly to TinkeringTurian himself. His profile is available at
                            <a target="_blank" href="http://steamcommunity.com/id/TinkeringTurian/">http://steamcommunity.com/id/TinkeringTurian/</a>.
                            He'll be online on Steam most of the time he is awake, unless otherwise occupied. Send him a friend request, and he'll
                            usually add you immediately. In case he missed your request, or if he's currently unavailable, you may also leave a 
                            comment on his profile, and he'll get back to you as soon as he can.
                        </li>

                        <li class="text">
                            Secondly, the chat program Discord is an option.
                            The game's official Discord server may be joined via the following link:
                            <a target="_blank" href="https://discord.gg/kwSHRBE">https://discord.gg/kwSHRBE</a>.
                            TinkeringTurian's own Discord handle is <span class="bold">Lucario#5887</span>.
                        </li>

                        <li class="text">
                            Thirdly, if you have a Patreon account, you may report issues by posting about them on Kobold Adventure's Patreon page, available at
                            <a target="_blank" href="https://www.patreon.com/TinkeringTurian">https://www.patreon.com/TinkeringTurian</a>.
                            Make a community post, or comment on an update, and your issue will be investigated (and hopefully fixed) as soon as possible.
                        </li>
    
                        <li class="text">
                            Last, but not least, good old fashioned emailing is always an option. Definitely not the fastest way to report an issue, yet a lot
                            more reliable than reporting via Steam or Patreon. The email address you should send to is:
                            <a target="_blank" href="mailto:tinkeringturian@gmail.com">tinkeringturian@gmail.com</a>. This address will be checked about once
                            or twice daily. This is also where you should send all your fanmail.
                        </li>

                    </ul>

                    <p class="text">
                        If playing Kobold Adventure has given you the urge to contribute to the project, feel free to click the
                        <a target="_blank" href="credits/index.html">credits</a> button at the bottom left of the screen.
                        Ontop of the names of creators, contributors and donators, that page contains a short contribution guide.
                    </p>

                    <p class="text">
                        Should you have paid any amount of money to be allowed to view this screen, you have been ripped off. Kobold Adventure is a somewhat
                        open source project, and it always will be. It is published under the GNU General Public License, which means that anyone may run, 
                        study, share, copy, and modify the software however they wish, provided that the end result is once again published under the 
                        GNU General Public License. To obtain a copy of the source code, please contact the creator.
                    </p>

                    <p class="text">
                        In case you want to help the Kobold Adventure project, yet lack the ability, will or talent to contribute via writing, 
                        drawing art or providing moral support, you may always consider donating via the Patreon page, available at 
                        <a target="_blank" href="https://www.patreon.com/TinkeringTurian">https://www.patreon.com/TinkeringTurian</a>. Every little bit counts,
                        and there's even a few rewards and milestones. How exciting! If you don't feel like spending money on an online kobold molesting
                        simulator, that's perfectly fine too.
                    </p>

                    <p class="text">
                        Please note that by clicking the following button, you are confirming that you are at least eighteen years of age,
                        and that you are ready for an awesome adventure that may involve adult themes, including but not limited to: sex,
                        rape, drugs, prostitution, bestiality, extortion, violence, death, gore, filth, hand-holding and slavery. The
                        creator of Kobold Adventure is not liable for any psychological trauma you may sustain while playing.
                    </p>

                    <button class="button bigbutton" id="startbutton" ${continued() ? "disabled" : ""}>
                        Begin your adventure
                    </button>`;
    
    // PRIVATE FUNCTIONS \\     function privateFunction(){}
    
    /**
     * Signals the scene has been continued.
     */
    function continueScene() {
        global.kobold.history.setKey(that.id, "continue", true);
    }
    
    /**
     * Returns whether or not the scene has continued.
     * @returns {boolean} True if the scene has continued, false otherwise.
     */
    function continued() {
        return global.kobold.history.has(that.id, "continue");
    }
        
    /**
     * Builds the tab as a HTML string.
     * @returns {string} The tab, as a HTML string.
     */
    function buildTab() {
        var tab = global.ui.buildGenericHeader();
        tab += content;
        tab += global.ui.buildGenericFooter();
        return tab;
    }
    
    /**
     * Registers all the required button listeners.
     */
    function registerListeners() {
        $("#" + "startbutton").click(startButtonClick);
    }
    
    /**
     * Processes the start button being clicked.
     */
    function startButtonClick() {
        global.ui.fadeOutContent(function(){
            continueScene();
            global.sceneEnd();
            global.sceneLoader.loadScene("Introduction"); 
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "TitleScreen";
    this.name = "Titlescreen";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Loads this scene.
     */
    this.load = function() {
        global.currentScene = that.id;
        global.currentSceneName = that.name;
        global.currentSceneFolder = that.subfolder ? that.subfolder : "";
        global.kobold.history.addToSceneStack(that.id);
        global.ui.applyTheme();
        var tab = buildTab();
        global.ui.loadToMain(tab);
        registerListeners();
    };
}

(function () {
    var scene = new TitleScreen();
    global.sceneLoader.registerScene(scene.id, scene);
})();
