/**
 * Confrontation section of Varanar, Night Two.
 * @param {NightTwoController} controller The Night Two controller.
 */
function NightTwoCrude(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var appeaseId = arguments.callee.name + "ButtonOne";
    var rudeId = arguments.callee.name + "ButtonTwo";

    var toAppease = new NightTwoCrudeAppease(ctrl);
    var toRude = new NightTwoCrudeRude(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You decide [b]not[/b] to empower the group's belligerent behavior.
                            Instead of giving them attention, or even the [b]satisfaction[/b] of chasing after you,
                            you're going to walk right past the hoodlums without so much as [b]looking[/b] at them.
                            Tilting your head the other way,
                            staring at the front-faces of the buildings you pass as though you're inspecting them,
                            you begin to stride down the road.
                            As you approach, the group appears to simmer down a bit, your tactic of not paying them any mind seemingly effective.
                        [/p]
                        [p]
                            Looking away to the side, however, quickly proves to have been a mistake.
                            The moment you cross the delinquents' party, you suddenly [b]bump[/b] into something,
                            the unexpected collision almost making you fall back onto your butt.
                            Your gaze snapping forwards, you become aware that the [i]thing[/i] you walked into is none other than one of the men.
                            Taking a few steps backwards to regain your balance, you find your rear end pressing against something as well.
                            Another human.
                            It looks like, while you were [i]pretending[/i] not to notice them, the drunkards somehow managed to surround you!
                        [/p]
                        [p]
                            The man you bumped into last pushes you forwards, into the middle of the little [i]circle[/i] they've formed.
                            While they were quiet enough to sneak up on you, now that they have you surrounded, the group soon returns to its rowdy nature.
                            Cruel jokes and a myriad of insults are hurled your way.
                            "[color=purple]Who left the cage open?![/color]"
                            "[color=dred]It lost its collar![/color]"
                            "[color=brown]My wife cooked two of you for dinner last night![/color]"
                            Growing concerned, you desperately look around for a way out, yet they have you [b]completely[/b] encircled.
                            Any time you take so much as a step towards them, you get roughly [b]shoved[/b] back into the very centre of the group.
                        [/p]
                        [p]
                            One of the humans breaks formation, stepping towards you with a swaying gait that [b]screams[/b] drunkenness.
                            You fear for the worst, but instead of the [b]brutal pummeling[/b] you half-expected,
                            the ruffian comes to a halt a few feet in front of you.
                            It seems he is sober enough to slur out a few coherent words:
                            "[color=bred]Me and...[/color]" *hic* "[color=bred]...my buddy Jacoby back there was arguin' 'bout you [i]lizards[/i] earlier.[/color]"
                            The brute takes a lengthy pause to consider his next words, his inebriated brain clearly working overtime.
                            "[color=bred]He says your kind is good for [b]nothing[/b].
                            I disagree.
                            You kobolds are good at [b]kissing ass[/b], especially when it comes to [b]civilized people[/b] like [b]us[/b].
                            I think you kiss ass better than [b]any[/b] other species!
                            So, which one of us is right?[/color]"
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildAppeaseChoice() {
        var disabled = ctrl.lewdCrude.has() ? "disabled" : "";
        var isSelected = ctrl.lewdCrude.get() === NightTwoCrudeChoice.APPEASE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${appeaseId}" ${disabled}>Appeasing</button>`;

        var tooltip = global.parser.parse(`Attempt to appease the man. If you play along, the group'll have no reason to hurt you, right?`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 230px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildRudeChoice() {
        var disabled = ctrl.lewdCrude.has() ? "disabled" : "";
        var isSelected = ctrl.lewdCrude.get() === NightTwoCrudeChoice.RUDE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${rudeId}" ${disabled}>Rude</button>`;

        var tooltip = global.parser.parse(`Don't give them an inch. Refuse to play along. Give them a piece of your mind, and send them on their way.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You are: </div>`;
        choice += buildRudeChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildAppeaseChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + appeaseId), $("#" + rudeId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerAppeaseListener() {
        $("#" + appeaseId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.lewdCrude.set(NightTwoCrudeChoice.APPEASE);
            loadNextPart(toAppease);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerRudeListener() {
        $("#" + rudeId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.lewdCrude.set(NightTwoCrudeChoice.RUDE);
            loadNextPart(toRude);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.lewdCrude.change();
        part += buildChoice();
        part += `</div>`;
        part += toAppease.build();
        part += toRude.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        toAppease.registerListeners();
        toRude.registerListeners();

        if (ctrl.lewdCrude.has()) {
            return;
        }

        registerAppeaseListener();
        registerRudeListener();
    };
}

var NightTwoCrudeChoice = {
    RUDE: 1,
    APPEASE: 2
};

