/**
 * Flee section of Varanar, Night Two.
 * @param {NightTwoController} controller The Night Two controller.
 */
function NightTwoRunSurvivalContinue(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Half an hour later, you manage to open one of your eyelids anew, the swelling slowly fading.
                            Just in time to witness the sun slowly starting to rise above the rooftops.
                            The sunrise inspires you.
                            You steel your mind.
                            You aren't dead yet.
                            You can't stay here.
                            There's some things you need to [b]fix[/b] before you can get up, though.
                            This is going to hurt.
                        [/p]
                        [p]
                            Bringing both your hands to your snout, you forcibly [b]twist[/b] your broken nose-bones back into place,
                            a sickening [b]snap[/b] accompanying the horrifying [b]pain[/b] of two of your bones grinding against one another.
                            You let out a shrill shriek of suffering, although self-inflicted this time around.
                            Your cryiing and your breathing both intensify, but as the new pain begins to fade, your muzzle feels slightly [b]better[/b] off as a whole.
                            Like it was [b]bent out of place[/b] during the intense beatdown, and you [b]set it straight[/b] just now.
                            It is a [b]good[/b] pain.
                        [/p]
                        [p]
                            After wallowing in your own misery for a little while longer, you wearily roll onto your heavily bruised stomach,
                            swiftly raising yourself to your knees to avoid having to lie ontop of fresh injuries.
                            Your legs were mostly spared during the beating.
                            Leaning back, resting your weight ontop of your calves, you inspect the damage done to your body.
                            You are bruised all over, with several small, but lengthy cuts along your side and your chest.
                            You think one of your ribs is broken, but you aren't sure.
                        [/p]
                        [p]
                            Your stomach hurts significantly.
                            You think you may have severe internal injuries, but you're no doctor.
                            And even if you were, you doubt there's a cure for [i]ruptured stomach[/i].
                            But you're a kobold.
                            Your kind has the uncanny ability to live through even the most grievous of injuries and come back swinging.
                            And even if your injuries [b]won't[/b] heal, you simply [b]refuse[/b] to die [b]here[/b], in the middle of the street.
                        [/p]
                        [p]
                            No.
                            You're [b]not[/b] going to die.
                            That's what [b]they[/b] -- the humans that beat you -- would want.
                            You are [b]tough[/b].
                            You're going to [b]live[/b], if just because your very existance serves to [b]taunt[/b] the people who did this to you.
                        [/p]
                        [p]
                            Driven by [b]grit[/b] and [b]determination[/b], by the sheer [b]will[/b] to live, you crawl to your feet.
                            With slow, unsteady paces, you begin to wobble in the general direction of the town square.
                            Every step you take seems to invigorate you further, empowering your sheer [b]stubbornness[/b], your [b]refusal[/b] to let go of life itself.
                            While your wounds remain severe, your mind is stalwartly set on overcoming them.
                        [/p]
                        [p]
                            The twinkle of magic you felt at midnight has all but faded.
                            You now realize you are but a lone, weak,
                            small kobold in a big city filled with people who can and [b]will[/b] maim, hurt, kill and perhaps even [b]rape[/b] you.
                            You can't let your guard down, ever.
                            Next time you do, it might end up costing you your life, as it already nearly has.
                            You need to stay tough if you want to perservere in the big city.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.nextSceneName, ctrl.nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.runSurvive.continued()) {
            return "";
        }

        global.ui.applyTheme("varanar_morning");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.endChange.change();
        part += buildChoice();
        if (!ctrl.nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.runSurvive.continued()) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (ctrl.nextSceneReady) {
            registerContinueListener();
        }
    };
}
